#!/usr/bin/python
# -*- coding: utf-8 -*-

   #########################################################################
 ##                                                                       ##
##           ┏━╸┏━┓╻ ╻┏━╸┏━┓   ╺┳╸╻ ╻╻ ╻┏┳┓┏┓ ┏┓╻┏━┓╻╻  ┏━╸┏━┓            ##
##           ┃  ┃ ┃┃┏┛┣╸ ┣┳┛    ┃ ┣━┫┃ ┃┃┃┃┣┻┓┃┗┫┣━┫┃┃  ┣╸ ┣┳┛            ##
##           ┗━╸┗━┛┗┛ ┗━╸╹┗╸    ╹ ╹ ╹┗━┛╹ ╹┗━┛╹ ╹╹ ╹╹┗━╸┗━╸╹┗╸            ##
##                         — www.flogisoft.com —                          ##
##                                                                        ##
############################################################################
##                                                                        ##
## Cover thumbnailer                                                      ##
##                                                                        ##
## Copyright (C) 2009  Fabien Loison (flo@flogisoft.com)                  ##
##                                                                        ##
## This program is free software: you can redistribute it and/or modify   ##
## it under the terms of the GNU General Public License as published by   ##
## the Free Software Foundation, either version 3 of the License, or      ##
## (at your option) any later version.                                    ##
##                                                                        ##
## This program is distributed in the hope that it will be useful,        ##
## but WITHOUT ANY WARRANTY; without even the implied warranty of         ##
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          ##
## GNU General Public License for more details.                           ##
##                                                                        ##
## You should have received a copy of the GNU General Public License      ##
## along with this program.  If not, see <http://www.gnu.org/licenses/>.  ##
##                                                                       ##
#########################################################################


import Image, urllib, hashlib, glob, os.path, stat, sys


#CONF
COVER_FILES = ['cover.png', 'cover.jpg', '.cover.png', '.cover.jpg',
		'Cover.png', 'Cover.jpg', '.Cover.png', '.Cover.jpg',
		'folder.png', 'folder.jpg', '.folder.png', '.folder.jpg',
		'Folder.png', 'Folder.jpg', '.Folder.png', '.Folder.jpg']

FG_FOLDER = '/opt/cover_thumbnailer/folder_fg.png'

DEFAULT_MUSIC_PICTURE = '/opt/cover_thumbnailer/music_nocover.png'
MUSIC_FG = '/opt/cover_thumbnailer/music_fg.png'
MUSIC_BG = '/opt/cover_thumbnailer/music_bg.png'


def get_music_path():
	path = ' '
	if os.path.isfile(os.environ.get('HOME')+'/.config/user-dirs.dirs'):
		file = open(os.environ.get('HOME')+'/.config/user-dirs.dirs','r')
		for line in file:
			if line[0:13] == 'XDG_MUSIC_DIR':
				path = line[15:].replace('"\n', '').replace('$HOME', os.environ.get('HOME'))
		file.close()
	return path


class thumb(object):
	def __init__(self, img_uri):
		self.img = Image.open(img_uri)
		self.thumb = None

	def create_thumb(self, size=96):
		width = self.img.size[0]
		height = self.img.size[1]
		if width > height:
			left = int((width - height)/2)
			upper = 0
			right = height + left
			lower = height
		else:
			left = 0
			upper = int((height - width)/2)
			right = width
			lower = width + upper
		self.thumb = self.img.crop((left, upper, right, lower))
		self.thumb.thumbnail((size, size), Image.ANTIALIAS)

	def add_fg(self, fg_picture):
		if os.path.isfile(fg_picture):
			fg = Image.open(fg_picture)
			self.thumb.paste(fg, (0,0), fg)

	def add_bg(self, bg_picture):
		if os.path.isfile(bg_picture):
			bg = Image.open(bg_picture)
			bg.paste(self.thumb, (18,0))
			self.thumb = bg

	def save_thumb(self, thumb_uri, format='PNG'):
		self.thumb.save(thumb_uri, format)


def do_thumb(path, output, thumb_size=128, fg=None, bg=None, default_pic=None):
	cover_path = None
	for cover in COVER_FILES:
		if os.path.isfile(path+'/'+cover):
			cover_path = path+'/'+cover
			break
	if cover_path == None and default_pic != None:
		cover_path = default_pic
	if cover_path != None and os.path.isfile(cover_path):
		pic = thumb(cover_path)
		pic.create_thumb(thumb_size)
		if bg != None:
			pic.add_bg(bg)
		if fg != None:
			pic.add_fg(fg)
		pic.save_thumb(output, 'PNG')


if len(sys.argv) == 3:
	input = urllib.url2pathname(sys.argv[1]).replace('file://', '')
	output = urllib.url2pathname(sys.argv[2]).replace('file://', '')
	MUSIC_PATH = get_music_path()
	if input[0:len(MUSIC_PATH)] == MUSIC_PATH and len(MUSIC_PATH) < len(input):
		do_thumb(input, output, 110, MUSIC_FG, MUSIC_BG, DEFAULT_MUSIC_PICTURE)
	else:
		do_thumb(input, output, 128, FG_FOLDER)


